@@ -1,50 +1,18 @@
-# -*- coding: utf-8 -*-
 #
 # Univention Configuration Registry
 #  Config Registry information: read information about registered Config Registry
 #  variables
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2007-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2007-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 import os
 import re
+from collections.abc import Iterable
 
 import univention.info_tools as uit
 
 
-try:
-    from typing import Dict, Iterable, List, Optional, Tuple  # noqa: F401
-except ImportError:
-    pass
-
 # default locale
 _locale = 'de'
 
@@ -52,20 +20,18 @@ _locale = 'de'
 class Variable(uit.LocalizedDictionary):
     """UCR variable description."""
 
-    def __init__(self, registered=True):
-        # type: (bool) -> None
+    def __init__(self, registered: bool = True) -> None:
         uit.LocalizedDictionary.__init__(self)
-        self.value = None  # type: Optional[str]
+        self.value: str | None = None
         self._registered = registered
 
-    def check(self):
-        # type: () -> List[str]
+    def check(self) -> list[str]:
         """
         Check description for completeness.
 
         :returns: List of missing settings.
         """
-        missing = []  # type: List[str]
+        missing: list[str] = []
         if not self._registered:
             return missing
 
@@ -78,25 +44,23 @@ class Variable(uit.LocalizedDictionary):
 class Category(uit.LocalizedDictionary):
     """UCR category description."""
 
-    def __init__(self):
-        # type: () -> None
+    def __init__(self) -> None:
         uit.LocalizedDictionary.__init__(self)
 
-    def check(self):
-        # type: () -> List[str]
+    def check(self) -> list[str]:
         """
         Check description for completeness.
 
         :returns: List of missing settings.
         """
-        missing = []  # type: List[str]
+        missing: list[str] = []
         for key in ('name', 'icon'):
             if not self.get(key, None):
                 missing.append(key)
         return missing
 
 
-class ConfigRegistryInfo(object):
+class ConfigRegistryInfo:
     """UCR variable and category descriptions."""
 
     BASE_DIR = '/etc/univention/registry.info'
@@ -105,8 +69,7 @@ class ConfigRegistryInfo(object):
     CUSTOMIZED = '_customized'
     FILE_SUFFIX = '.cfg'
 
-    def __init__(self, install_mode=False, registered_only=True, load_customized=True):
-        # type: (bool, bool, bool) -> None
+    def __init__(self, install_mode: bool = False, registered_only: bool = True, load_customized: bool = True) -> None:
         """
         Initialize variable and category descriptions.
 
@@ -114,48 +77,45 @@ class ConfigRegistryInfo(object):
         :param registered_only: `False` creates synthetic entries for all undescribed but set variables.
         :param load_customized: `False` deactivates loading customized descriptions.
         """
-        self.categories = {}  # type: Dict[str, Category]
-        self.variables = {}  # type: Dict[str, Variable]
-        self._patterns = {}  # type: Dict[str, List[Tuple[str, str]]]
+        self.categories: dict[str, Category] = {}
+        self.variables: dict[str, Variable] = {}
+        self._patterns: dict[str, list[tuple[str, str]]] = {}
         if not install_mode:
             import univention.config_registry as ucr  # circular import
-            self._configRegistry = ucr.ConfigRegistry()  # type: Optional[ucr.ConfigRegistry]
+            self._configRegistry: ucr.ConfigRegistry | None = ucr.ConfigRegistry()
             self._configRegistry.load()
             self.load_categories()
             self._load_variables(registered_only, load_customized)
         else:
             self._configRegistry = None
 
-    def check_categories(self):
-        # type: () -> Dict[str, List[str]]
+    def check_categories(self) -> dict[str, list[str]]:
         """
         Check all categories for completeness.
 
         :returns: dictionary of incomplete category descriptions.
         """
-        incomplete = {}  # type: Dict[str, List[str]]
+        incomplete: dict[str, list[str]] = {}
         for name, cat in self.categories.items():
             miss = cat.check()
             if miss:
                 incomplete[name] = miss
         return incomplete
 
-    def check_variables(self):
-        # type: () -> Dict[str, List[str]]
+    def check_variables(self) -> dict[str, list[str]]:
         """
         Check variables.
 
         :returns: dictionary of incomplete variable descriptions.
         """
-        incomplete = {}  # type: Dict[str, List[str]]
+        incomplete: dict[str, list[str]] = {}
         for name, var in self.variables.items():
             miss = var.check()
             if miss:
                 incomplete[name] = miss
         return incomplete
 
-    def read_categories(self, filename):
-        # type: (str) -> None
+    def read_categories(self, filename: str) -> None:
         """
         Load a single category description file.
 
@@ -173,8 +133,7 @@ class ConfigRegistryInfo(object):
                 cat[name] = value
             self.categories[cat_name] = cat
 
-    def load_categories(self):
-        # type: () -> None
+    def load_categories(self) -> None:
         """Load all category description files."""
         path = os.path.join(ConfigRegistryInfo.BASE_DIR, ConfigRegistryInfo.CATEGORIES)
         if os.path.exists(path):
@@ -182,14 +141,12 @@ class ConfigRegistryInfo(object):
                 self.read_categories(os.path.join(path, filename))
 
     @staticmethod
-    def _pattern_sorter(args):
-        # type: (Tuple) -> Tuple[Tuple[int, str], str]
+    def _pattern_sorter(args: tuple) -> tuple[tuple[int, str], str]:
         """Sort more specific (longer) regular expressions first."""
         pattern, data = args
         return ((len(pattern), pattern), data)
 
-    def check_patterns(self):
-        # type: () -> None
+    def check_patterns(self) -> None:
         """Match descriptions agains currently defined UCR variables."""
         # in install mode
         if self._configRegistry is None:
@@ -212,8 +169,7 @@ class ConfigRegistryInfo(object):
                     var[name] = value
                 self.variables[key] = var
 
-    def describe_search_term(self, term):
-        # type: (str) -> Dict[str, Variable]
+    def describe_search_term(self, term: str) -> dict[str, Variable]:
         """
         Try to apply a description to a search term.
 
@@ -223,7 +179,7 @@ class ConfigRegistryInfo(object):
         :param term: Search term.
         :returns: Dictionary mapping variable pattern to Variable info blocks.
         """
-        patterns = {}  # type: Dict[str, Variable]
+        patterns: dict[str, Variable] = {}
         for pattern, data in sorted(self._patterns.items(), key=ConfigRegistryInfo._pattern_sorter, reverse=True):
             regex = re.compile(pattern)
             match = regex.search(term)
@@ -238,14 +194,12 @@ class ConfigRegistryInfo(object):
                 patterns[pattern] = var
         return patterns
 
-    def write_customized(self):
-        # type: () -> None
+    def write_customized(self) -> None:
         """Persist the customized variable descriptions."""
         filename = os.path.join(ConfigRegistryInfo.BASE_DIR, ConfigRegistryInfo.VARIABLES, ConfigRegistryInfo.CUSTOMIZED)
         self._write_variables(filename)
 
-    def _write_variables(self, filename=None, package=None):
-        # type: (str | None, str | None) -> bool
+    def _write_variables(self, filename: str | None = None, package: str | None = None) -> bool:
         """
         Persist the variable descriptions into a file.
 
@@ -277,14 +231,12 @@ class ConfigRegistryInfo(object):
         except OSError:
             return False
 
-    def read_customized(self):
-        # type: () -> None
+    def read_customized(self) -> None:
         """Read customized variable descriptions."""
         filename = os.path.join(ConfigRegistryInfo.BASE_DIR, ConfigRegistryInfo.VARIABLES, ConfigRegistryInfo.CUSTOMIZED)
         self.read_variables(filename, override=True)
 
-    def read_variables(self, filename=None, package=None, override=False):
-        # type: (str | None, str | None, bool) -> None
+    def read_variables(self, filename: str | None = None, package: str | None = None, override: bool = False) -> None:
         """
         Read variable descriptions.
 
@@ -317,8 +269,7 @@ class ConfigRegistryInfo(object):
                 var.value = self._configRegistry.get(sec, None)
             self.variables[sec] = var
 
-    def _load_variables(self, registered_only=True, load_customized=True):
-        # type: (bool, bool) -> None
+    def _load_variables(self, registered_only: bool = True, load_customized: bool = True) -> None:
         """
         Read default and customized variable descriptions.
 
@@ -343,8 +294,7 @@ class ConfigRegistryInfo(object):
             if load_customized:
                 self.read_customized()
 
-    def get_categories(self):
-        # type: () -> Iterable[str]
+    def get_categories(self) -> Iterable[str]:
         """
         Return a list of category names.
 
@@ -352,8 +302,7 @@ class ConfigRegistryInfo(object):
         """
         return self.categories.keys()
 
-    def get_category(self, name):
-        # type: (str) -> Optional[Category]
+    def get_category(self, name: str) -> Category | None:
         """
         Returns a category object associated with the given name or None.
 
@@ -364,8 +313,7 @@ class ConfigRegistryInfo(object):
             return self.categories[name.lower()]
         return None
 
-    def get_variables(self, category=None):
-        # type: (str | None) -> Dict[str, Variable]
+    def get_variables(self, category: str | None = None) -> dict[str, Variable]:
         """
         Return dictionary of variable info blocks belonging to given category.
 
@@ -374,7 +322,7 @@ class ConfigRegistryInfo(object):
         """
         if not category:
             return self.variables
-        temp = {}  # type: Dict[str, Variable]
+        temp: dict[str, Variable] = {}
         for name, var in self.variables.items():
             categories = var.get('categories')
             if not categories:
@@ -383,8 +331,7 @@ class ConfigRegistryInfo(object):
                 temp[name] = var
         return temp
 
-    def get_variable(self, key):
-        # type: (str) -> Optional[Variable]
+    def get_variable(self, key: str) -> Variable | None:
         """
         Return the description of a variable.
 
@@ -393,8 +340,7 @@ class ConfigRegistryInfo(object):
         """
         return self.variables.get(key, None)
 
-    def add_variable(self, key, variable):
-        # type: (str, Variable) -> None
+    def add_variable(self, key: str, variable: Variable) -> None:
         """
         Add a new variable information item or overrides an old entry.
 
@@ -403,8 +349,7 @@ class ConfigRegistryInfo(object):
         """
         self.variables[key] = variable
 
-    def match_pattern(self, key):
-        # type: (str) -> Optional[Variable]
+    def match_pattern(self, key: str) -> Variable | None:
         """
         Searches the variable info, whichs regex pattern patches the given key.
 
@@ -423,8 +368,7 @@ class ConfigRegistryInfo(object):
         return None
 
 
-def set_language(lang):
-    # type: (str) -> None
+def set_language(lang: str) -> None:
     """Set the default language."""
     global _locale
     _locale = lang
