@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2014-2024 Univention GmbH
+# SPDX-FileCopyrightText: 2014-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 import sys
@@ -24,7 +24,7 @@ def ucr0(tmpdir, monkeypatch, request):
     return ucr
 
 
-@pytest.fixture()
+@pytest.fixture
 def ucrf(ucr0):
     """Return a pre-initialized UCR instance."""
     ucr = be.ConfigRegistry(write_registry=be.ConfigRegistry.LDAP)
@@ -39,7 +39,7 @@ def ucrf(ucr0):
     return ucr0
 
 
-@pytest.fixture()
+@pytest.fixture
 def tmpucr(monkeypatch, tmpdir):
     fname = tmpdir / 'custom.conf'
     monkeypatch.setenv('UNIVENTION_BASECONF', str(fname))
