@@ -1,7 +1,6 @@
 #!/usr/bin/python3
-# vim:set fileencoding=utf-8:
 # pylint: disable-msg=C0103,E0611,R0904
-# SPDX-FileCopyrightText: 2014-2024 Univention GmbH
+# SPDX-FileCopyrightText: 2014-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Unit test for univention.config_registry.backend."""
@@ -85,7 +84,7 @@ def test_run_module(funcname, mocker):
     pytest.param("# ", set(), "# Warning: ", id="#"),
     pytest.param(";", set(), ";Warnung: ", id=";"),
     pytest.param("// ", {"tmpl"}, "// \ttmpl\n", id="//"),
-    pytest.param(";", {u"Dom\u00e4ne"}, u";\tDom\u00e4ne\n", id="unicode"),
+    pytest.param(";", {"Dom\u00e4ne"}, ";\tDom\u00e4ne\n", id="unicode"),
 ])
 def test_warning_string(prefix, srcfiles, expected):
     assert expected in ucrh.warning_string(prefix, srcfiles=srcfiles)
@@ -96,9 +95,9 @@ def test_ConfigHandler():
         ucrh.ConfigHandler()(({}, {}))
 
 
-class TestConfigHandlerDiverting(object):
+class TestConfigHandlerDiverting:
 
-    @pytest.fixture()
+    @pytest.fixture
     def hdivert(self):
         return ucrh.ConfigHandlerDiverting("/divert")
 
@@ -207,7 +206,7 @@ def test_ConfigHandlerMultifile(mocker):
     h.remove_subfile("")
     h.remove_subfile("subfile2")
 
-    return  # TODO
+    return  # TODO:
 
     mocker.patch("univention.config_registry.handler.run_module")
     mocker.patch("univention.config_registry.handler.run_script")
@@ -223,7 +222,7 @@ def test_ConfigHandlerFile(mocker):
     h = ucrh.ConfigHandlerFile("file.from", "file.to")
     assert h.need_divert()
 
-    return  # TODO
+    return  # TODO:
 
     mocker.patch("univention.config_registry.handler.run_module")
     mocker.patch("univention.config_registry.handler.run_script")
@@ -275,13 +274,13 @@ def test_grep_variables(tmpl, vars):
     assert ucrh.grep_variables(tmpl) == vars
 
 
-@pytest.fixture()
+@pytest.fixture
 def handler0(mocker):
     """Return empty dummy handler."""
     return mocker.MagicMock(preinst=None, postinst=None, user=None, group=None, mode=None)
 
 
-@pytest.fixture()
+@pytest.fixture
 def handlers(tmpcache):
     """Return :py:class:`ConfigHandlers` instance with private cache directory."""
     handlers = ucrh.ConfigHandlers()
@@ -413,30 +412,30 @@ class TestConfigHandlers:
         assert h2._subfiles == handlers._subfiles
         assert h2._multifiles == handlers._multifiles
 
-    @pytest.mark.skip()
+    @pytest.mark.skip
     def test_update(self, handlers):
         pass
 
-    @pytest.mark.skip()
+    @pytest.mark.skip
     def test_update_divert(self, handlers):
         pass
 
-    @pytest.mark.skip()
+    @pytest.mark.skip
     def test_register(self, handlers):
         pass
 
-    @pytest.mark.skip()
+    @pytest.mark.skip
     def test_unregister(self, handlers):
         pass
 
-    @pytest.mark.skip()
+    @pytest.mark.skip
     def test_call(self, handlers):
         pass
 
-    @pytest.mark.skip()
+    @pytest.mark.skip
     def test_commit(self, handlers):
         pass
 
-    @pytest.mark.skip()
+    @pytest.mark.skip
     def test_call_handler(self, handlers):
         pass
