@@ -1,6 +1,5 @@
 #!/usr/bin/python3
-# vim:set fileencoding=utf-8:
-# SPDX-FileCopyrightText: 2022-2024 Univention GmbH
+# SPDX-FileCopyrightText: 2022-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Unit test for univention.config_registry.validation."""
@@ -274,7 +273,7 @@ def test_json(value, expected):
     assert jj.is_valid(value) == expected
 
 
-@pytest.fixture()
+@pytest.fixture
 def var():
     """Fake Variable type."""
     return {
